#
# spec file for package ocaml-gettext
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with ocaml_gettext_testsuite
%define build_flavor %nil
%if "%build_flavor" == "testsuite"
%if %{without ocaml_gettext_testsuite}
ExclusiveArch:  do-not-build
%endif
%define nsuffix -testsuite
%else
%define nsuffix %nil
%endif

%define     pkg ocaml-gettext
Name:           %pkg%nsuffix
Version:        0.4.2
Release:        4.1
%{?ocaml_preserve_bytecode}
Summary:        OCaml library for i18n
License:        SUSE-LGPL-2.0-with-linking-exception
Group:          Development/Languages/OCaml
URL:            https://opam.ocaml.org/packages/gettext
Source0:        %pkg-%version.tar.xz
BuildRequires:  ocaml
BuildRequires:  ocaml-dune
BuildRequires:  ocaml-rpm-macros >= 20230101
%if 1
BuildRequires:  ocamlfind(compiler-libs.common)
BuildRequires:  ocamlfind(cppo)
BuildRequires:  ocamlfind(dune.configurator)
BuildRequires:  ocamlfind(fileutils)
%endif

%if "%build_flavor" == "testsuite"
BuildRequires:  ocamlfind(fileutils)
BuildRequires:  ocamlfind(gettext)
BuildRequires:  ocamlfind(oUnit)
BuildRequires:  ocamlfind(str)
%endif

#
# camomile was used in old versions of this pkg.
Obsoletes:      ocaml-gettext-camomile < %version-%release
Obsoletes:      ocaml-gettext-stub < %version-%release
Obsoletes:      ocaml-gettext-stub-debuginfo < %version-%release
Obsoletes:      ocaml-gettext-stub-devel < %version-%release
Provides:       ocaml-gettext-camomile = %version-%release
Provides:       ocaml-gettext-stub = %version-%release
Provides:       ocaml-gettext-stub-debuginfo = %version-%release
Provides:       ocaml-gettext-stub-devel = %version-%release

%description
Ocaml-gettext provides support for internationalization of Ocaml
programs.

Constraints :

* provides a pure Ocaml implementation,
* the API should be as close as possible to GNU gettext,
* provides a way to automatically extract translatable
  strings from Ocaml source code.

%package        devel
Summary:        Development files for %name
Group:          Development/Languages/OCaml
Requires:       %name = %version
Obsoletes:      ocaml-gettext-camomile-devel < %version-%release
Provides:       ocaml-gettext-camomile-devel = %version-%release

%description    devel
The %name-devel package contains libraries and signature files for
developing applications that use %name.

%prep
%autosetup -p1 -n %pkg-%version

%build
dune_release_pkgs='gettext,gettext-stub'
%ocaml_dune_setup
%if "%build_flavor" == ""
%ocaml_dune_build
%endif

%install
%if "%build_flavor" == ""
%ocaml_dune_install
%ocaml_create_file_list
grep -m1 '%%dir' %name.files.devel | tee %name.files.stub-devel
%endif

%if "%build_flavor" == "testsuite"
%check
%ocaml_dune_test
%endif

%if "%build_flavor" == ""
%files -f %name.files
%_bindir/*
%_mandir/*/*

%files devel -f %name.files.devel

%endif

%changelog
* Tue Aug  8 2023 ohering@suse.de
- Remove dependency to Camomile
  The only consumer of this pkg (virt-top) does not need it
* Mon Apr  4 2022 ohering@suse.de
- add bcond ocaml_gettext_testsuite to disable failing testsuite
* Thu Jan 21 2021 ohering@suse.de
- remove dependency to ounit via _multibuild
* Thu Aug 20 2020 ohering@suse.de
- Update to version 0.4.2
  Compatibility with OCaml 4.11
* Fri Nov  1 2019 ohering@suse.de
- Require current dune macros
- Update to version 0.4.1, via _service file
  Improve documentation layout.
  Migrate build system to dune.
  Move ocaml-xgettext from Camlp4 to ppx.
- Remove sub packages
- Remove ocaml-gettext-unix.patch
- Remove ocaml-gettext-0.3.5-use-ocamlopt-g.patch
* Tue Jul 25 2017 ohering@suse.de
- Use Group: Development/Languages/OCaml
* Mon Jul 17 2017 ohering@suse.de
- Wrap specfile conditionals to fix quilt setup
* Mon Jul 17 2017 ohering@suse.de
- Remove autodeps for pre openSUSE 12.1 releases
* Wed May 10 2017 olaf@aepfle.de
- stub-devel requires stub (bsc#1031359)
* Fri May 20 2016 ohering@suse.de
- Fix compile error with ocaml-4.03 (fate#320836)
  ocaml-gettext-unix.patch
  reenable all archs
* Tue Nov 10 2015 ohering@suse.de
- Add hardcoded Provides for pre 12.1 repos
* Wed Sep 16 2015 mlatimer@suse.com
- Exclude s390x architecture
* Wed Jun 24 2015 olaf@aepfle.de
- Update License to SUSE-LGPL-2.0-with-linking-exception
* Mon Dec  8 2014 mlatimer@suse.com
- Update spec file to use ocaml-rpm-macros, remove
  ExclusiveArch, and ensure bytecode is built
* Fri Dec  5 2014 mlatimer@suse.com
- Initial commit using upstream version 3.5
